@@ -198,6 +198,7 @@ class PrEvent(Document):
 
 
 class PipelineRun(Document):
+    """Pipeline events"""
     name = StringField(max_length=120, required=True)
     number = IntField()
     repo = StringField(max_length=200)
@@ -220,16 +221,19 @@ class PipelineRun(Document):
 
 
 class Group(Document):
+    """Group data"""
     name = StringField(max_length=120, primary_key=True, required=True)
     children = ListField(StringField(max_length=120))
 
 
 class Set(Document):
+    """Set data"""
     name = StringField(max_length=120, primary_key=True, required=True)
     children = ListField(StringField(max_length=120))
 
 
 class JiraIssue(Document):
+    """Agile issues"""
     issue_id = StringField()
     issue_key = StringField(primary_key=True, required=True)
     issuetype_name = StringField()
@@ -253,15 +257,25 @@ class JiraIssue(Document):
 
 
 class SkippedRepo(Document):
+    """Skipped repos logged from celery"""
     repo_name = StringField(max_length=120, primary_key=True, required=True)
     error = StringField(max_length=10000)
 
 
+class LineHistory(EmbeddedDocument):
+    """A sub-document for user contribution history"""
+
+    index = IntField()
+    user = StringField()
+    commit = StringField()
+    line_type = StringField()
+    line_number = IntField()
+    code = StringField()
+
+
 class UserContribution(Document):
+    """File line commit history"""
     organization = StringField()
     repository = StringField()
-    user = StringField()
     file = StringField()
-    line_id = StringField()
-    line_number = IntField()
-    timestamp = DateTimeField()
+    line_history = EmbeddedDocumentListField(LineHistory)
